import { alias, int, mysqlTable, varchar } from 'drizzle-orm/mysql-core';
import type { MySql2Database } from 'drizzle-orm/mysql2';
import { user } from './user.ts';
import { eq } from 'drizzle-orm';

type Database = MySql2Database<{ death: typeof death }>;

export const death = mysqlTable('death', {
  message: varchar('message', { length: 1024 }).notNull(),
  deadUserId: int('dead_user_id')
    .notNull()
    .references(() => user.id),
  killerUserId: int('killer_user_id').references(() => user.id)
});

export type AddDeathReq = {
  message: string;
  killerUserId?: number;
  deadUserId: number;
};

export type GetDeathByUserIdReq = {
  userId: number;
};

export type GetDeathsReq = {};

export async function addDeath(db: Database, values: AddDeathReq) {
  await db.insert(death).values(values);
}

export async function getDeathByUserId(db: Database, values: GetDeathByUserIdReq) {
  return db.query.death.findFirst({
    where: eq(death.deadUserId, values.userId)
  });
}

export async function getDeaths(db: Database, _values: GetDeathsReq) {
  const killed = alias(user, 'killed');
  const killer = alias(user, 'killer');

  return db
    .select({
      message: death.message,
      killed: {
        id: killed.id,
        username: killed.username
      },
      killer: {
        id: killer.id,
        username: killer.username
      }
    })
    .from(death)
    .innerJoin(killed, eq(death.deadUserId, killed.id))
    .leftJoin(killer, eq(death.killerUserId, killer.id));
}
